# Generated by Django 2.1.7 on 2019-02-15 21:54

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [("ranch", "0002_loggedtask_queue")]

    operations = [
        migrations.AddField(
            model_name="loggedtask",
            name="rollbar_occurrence",
            field=models.UUIDField(null=True),
        )
    ]
